.. -*- mode: rst -*-

|Travis|_ |AppVeyor|_ |Codecov|_ |CircleCI|_ |ReadTheDocs|_

.. |Travis| image:: https://travis-ci.org/scikit-learn-contrib/project-template.svg?branch=master
.. _Travis: https://travis-ci.org/scikit-learn-contrib/project-template

.. |AppVeyor| image:: https://ci.appveyor.com/api/projects/status/coy2qqaqr1rnnt5y/branch/master?svg=true
.. _AppVeyor: https://ci.appveyor.com/project/glemaitre/project-template

.. |Codecov| image:: https://codecov.io/gh/scikit-learn-contrib/project-template/branch/master/graph/badge.svg
.. _Codecov: https://codecov.io/gh/scikit-learn-contrib/project-template

.. |CircleCI| image:: https://circleci.com/gh/scikit-learn-contrib/project-template.svg?style=shield&circle-token=:circle-token
.. _CircleCI: https://circleci.com/gh/scikit-learn-contrib/project-template/tree/master

.. |ReadTheDocs| image:: https://readthedocs.org/projects/neuro-evolution/badge/?version=latest
.. _ReadTheDocs: https://neuro-evolution.readthedocs.io/en/latest/?badge=latest

NeuroEvolution -> scikit-learn compatible NEAT & WANN
============================================================

.. _scikit-learn: https://scikit-learn.org

NEAT is a method developed by Kenneth O. Stanley for evolving arbitrary neural networks. It's an established topology search algorithm notable for its ability to optimize the weights and structure of networks simultaneously

.. _neuro-evolution: https://pypi.org/project/neuro-evolution/
.. _neat-python: https://github.com/CodeReclaimers/neat-python
.. _weight-agnostic-neural-networks: https://github.com/google/brain-tokyo-workshop/tree/master/WANNRelease

neuro-evolution_ package is based on a pure python implementation of NEAT called neat-python_ with the addition
of weight agnostic neural networks that are based on weight-agnostic-neural-networks_

